%(C)  Moo K. Chung mkchung@wisc.edu 
%     Department of Biostatistics and Medical Informatics
%     University of Wisconsin-Madison
%

% The code is downloaded from
% http://brainimaging.waisman.wisc.edu/~chung/tracts/
%
% Reference
% The following two references give the detailed explanation of the technique.
%
% [1] Chung, M.K. Adluru, N., Lee, J.E., Lazar, M., Lainhart, J.E., Alexander, A.L. 
%     2010. Cosine series representation of 3D curves and its application to white 
%     matter fiber bundles in diffusion tensor imaging. Statistics and Its Interface  3:69-80.
%
% [2] Chung, M.K. 2013. Statistical and Computational Methods in Brain Image Analysis.  
%     CRC Press. The detail is given in Chapter 10 of this book.
%
% Update history: 
% Feb 1, 2017


%loading data
SL=get_streamlines('001_spd_tracts.Bfloat',[1.5 1.75 2.25]);
tract=SL{1000}';
figure; plot3(tract(1,:),tract(2,:),tract(3,:),'.b')


% parameterization
[arc_length  para]=parameterize_arclength(tract);

figure;
subplot(3,1,1); plot(para, tract(1,:));
subplot(3,1,2); plot(para, tract(2,:));
subplot(3,1,3); plot(para, tract(3,:));

[wfs beta]=WFS_tracts(tract,para,19);
figure; plot3(tract(1,:),tract(2,:),tract(3,:),'.y') %original data
hold on; plot3(wfs(:,1),wfs(:,2),wfs(:,3),'-k') %reconstruction

%wfs=WFS_resample(beta,19, [0:0.01:1]); %resample only using 101 points
%hold on; plot3(wfs(:,1),wfs(:,2),wfs(:,3),'-r') % resampling


%-----------------------------------
% Avearging the cosine representation
% the matheamtical justifiation is given in [1]

tract2 = tract + normrnd(0,0.5,3,491); %add noise
hold on; plot3(tract2(1,:),tract2(2,:),tract2(3,:),'.y') %simulation

[arc_length2  para2]=parameterize_arclength(tract2);
[wfs2 beta2]=WFS_tracts(tract2,para2,19);
hold on; plot3(wfs2(:,1),wfs2(:,2),wfs2(:,3),'-k') %reconstruction

% avearge of tract + tract2

beta_a= (beta + beta2)/2;
para_a = [1:200]/200;
wfs_a=WFS_resample(beta_a,19, para_a);
hold on; plot3(wfs_a(:,1),wfs_a(:,2),wfs_a(:,3),'-r') %reconstruction


%------------------------------------
% simulation example given in paper [1]
t=0:0.1:10
tract=[t.*sin(t); t.*cos(t); t];
figure; plot3(tract(1,:),tract(2,:),tract(3,:),'.b') %simulation

[arc_length  para]=parameterize_arclength(tract1);
[wfs beta]=WFS_tracts(tract,para,19);
hold on; plot3(wfs(:,1),wfs(:,2),wfs(:,3),'r') %reconstruction


%------------------------
%stream tube visualization
figure; figure_streamtube(tract', 0.5, [1 .3 .3]);
camlight



%-------------------
% heat kernel smoothing

load EEG.mat  %5 EEG

% heat kernel smoothing
x=[1:3500]/3500;
k=2000;
sigma=0.0001;
[wfs beta]=WFS_COSINE(EEG(1,:)',x',k,sigma);
figure; plot(EEG(1,:), '.k');
hold on; plot(wfs, 'r', 'linewidth',1)





